@@ -108,7 +108,7 @@ class Deployment(object):
                             raise ErrorExit()
                     if update:
                         charm.update(build=True)
-                    return
+                    continue
             charm.fetch()
 
     def resolve(self, cli_overides=()):
