@@ -2,6 +2,7 @@ import base64
 import StringIO
 import os
 
+
 from deployer.config import ConfigStack
 from deployer.deployment import Deployment
 from deployer.utils import setup_logging
@@ -16,7 +17,9 @@ class DeploymentTest(Base):
             debug=True, verbose=True, stream=StringIO.StringIO())
 
     def test_deployer(self):
-        d = ConfigStack(["test_data/blog.yaml"]).get('wordpress-prod')
+        d = ConfigStack(
+            [os.path.join(
+                self.test_data_dir, "blog.yaml")]).get('wordpress-prod')
         services = d.get_services()
         self.assertTrue([s for s in services if s.name == "newrelic"])
 
